@@ -9,16 +9,16 @@ use File::Copy;
 my $file = 't/sample.data';
 my $orig = 't/sample.data.orig';
 
-my $params = {
+my %params = (
                 file => '.',
                 #copy => 't/inject_after.data',
-                #pre_filter => 'subs && objects',
+                #pre_filter => ['subs', 'objects'],
                 engine => 'all',
                 #search => 'this',
                 #code => ['# comment line one', '# comment line 2' ],
-              };
+              );
 
-my $des = Devel::Examine::Subs->new($params);
+my $des = Devel::Examine::Subs->new(%params);
 
-my $struct = $des->run($params);
+my $struct = $des->run(\%params);
 
